==> ejc-techmanagement-api-3.0.0-20230811.074109-43-sources.jar: com/ejianc/business/techmanagement/vo/SpecialProgramVO.java <==
package com.ejianc.business.techmanagement.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 专项方案
 * 
 * @author generator
 * 
 */
public class SpecialProgramVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String createUserName; // 创建人名称
    private String modifyUserName; // 修改人名称
    private String billCode; // 单据编码
    private String billName; // 单据名称
    private String createScheduledTime; // 编制计划时间
    private Long professionalClassificationId; // 专业分类Id
    private Boolean supervisionApprovalFlag; // 监理审批标识 0-否， 1-是
    private String memo; // 备注
    private Integer billState; // 单据状态
    private Date commitDate; // 提交日期
    private String commitUserName; // 提交人名称
    private String commitUserCode; // 提交人账号
    private Date effectiveDate; // 生效日期
    private String supervisionApprovalFlagStr; //审批

    public String getSupervisionApprovalFlagStr() {
        return supervisionApprovalFlagStr;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    private String billStateName; //单据审批状态名称
    

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getModifyUserName() {
        return modifyUserName;
    }

    public void setModifyUserName(String modifyUserName) {
        this.modifyUserName = modifyUserName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getBillName() {
        return billName;
    }

    public void setBillName(String billName) {
        this.billName = billName;
    }
    public String getCreateScheduledTime() {
        return createScheduledTime;
    }

    public void setCreateScheduledTime(String createScheduledTime) {
        this.createScheduledTime = createScheduledTime;
    }


    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getProfessionalClassificationId() {
        return professionalClassificationId;
    }

    @ReferDeserialTransfer
    public void setProfessionalClassificationId(Long professionalClassificationId) {
        this.professionalClassificationId = professionalClassificationId;
    }

    public Boolean getSupervisionApprovalFlag() {
        return supervisionApprovalFlag;
    }

    public void setSupervisionApprovalFlag(Boolean supervisionApprovalFlag) {
        this.supervisionApprovalFlag = supervisionApprovalFlag;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }

    public void setSupervisionApprovalFlagStr(String supervisionApprovalFlagStr) {
        this.supervisionApprovalFlagStr = supervisionApprovalFlagStr;
    }
}

==> ejc-techmanagement-api-3.0.0-20231218.113317-59-sources.jar: com/ejianc/business/techmanagement/vo/SpecialProgramVO.java <==
package com.ejianc.business.techmanagement.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 专项方案
 * 
 * @author generator
 * 
 */
public class SpecialProgramVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String modifyUserName; // 修改人名称
    private String billCode; // 单据编码
    private String billName; // 单据名称
    private String createScheduledTime; // 编制计划时间
    private Long professionalClassificationId; // 专业分类Id
    private Boolean supervisionApprovalFlag; // 监理审批标识 0-否， 1-是
    private String memo; // 备注
    private Integer billState; // 单据状态
    private Date commitDate; // 提交日期
    private String commitUserName; // 提交人名称
    private String commitUserCode; // 提交人账号
    private Date effectiveDate; // 生效日期
    private String supervisionApprovalFlagStr; //审批
    private String billStateName; //单据审批状态名称
    private Long projectId; //项目Id
    private String projectName; //项目名称
    private String projectCode; //项目编码

    private Long orgId; //项目部Id
    private String orgName; //项目部名称
    private String orgCode; //项目部编码

    private Long parentOrgId; //项目部上级组织Id
    private String parentOrgName; //项目部上级组织名称
    private String parentOrgCode; //项目部上级组织编码

    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getSupervisionApprovalFlagStr() {
        return supervisionApprovalFlagStr;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getModifyUserName() {
        return modifyUserName;
    }

    public void setModifyUserName(String modifyUserName) {
        this.modifyUserName = modifyUserName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getBillName() {
        return billName;
    }

    public void setBillName(String billName) {
        this.billName = billName;
    }
    public String getCreateScheduledTime() {
        return createScheduledTime;
    }

    public void setCreateScheduledTime(String createScheduledTime) {
        this.createScheduledTime = createScheduledTime;
    }


    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getProfessionalClassificationId() {
        return professionalClassificationId;
    }

    @ReferDeserialTransfer
    public void setProfessionalClassificationId(Long professionalClassificationId) {
        this.professionalClassificationId = professionalClassificationId;
    }

    public Boolean getSupervisionApprovalFlag() {
        return supervisionApprovalFlag;
    }

    public void setSupervisionApprovalFlag(Boolean supervisionApprovalFlag) {
        this.supervisionApprovalFlag = supervisionApprovalFlag;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }

    public void setSupervisionApprovalFlagStr(String supervisionApprovalFlagStr) {
        this.supervisionApprovalFlagStr = supervisionApprovalFlagStr;
    }
}
